@@ -1,7 +1,7 @@
 # Accelerator for pip, the Python package manager.
 #
 # Author: Peter Odding <peter.odding@paylogic.eu>
-# Last Change: March 20, 2014
+# Last Change: May 15, 2014
 # URL: https://github.com/paylogic/pip-accel
 #
 # TODO Permanently store logs in the pip-accel directory (think about log rotation).
@@ -20,7 +20,7 @@ taking a look at the following functions:
 """
 
 # Semi-standard module versioning.
-__version__ = '0.12'
+__version__ = '0.12.1'
 
 # Standard library modules.
 import os
@@ -30,8 +30,15 @@ import shutil
 import sys
 import tempfile
 import textwrap
-import urllib
-import urlparse
+
+try:
+    # Python 2.x.
+    from urllib import unquote
+    from urlparse import urlparse
+except ImportError:
+    # Python 3.x.
+    from urllib.parse import unquote
+    from urllib.parse import urlparse
 
 # Modules included in our package.
 from pip_accel.bdist import get_binary_dist, install_binary_dist
@@ -122,7 +129,7 @@ def print_usage():
     """
     Report the usage of the pip-accel command to the console.
     """
-    print textwrap.dedent("""
+    print(textwrap.dedent("""
         Usage: pip-accel [ARGUMENTS TO PIP]
 
         The pip-accel program is a wrapper for pip, the Python package manager. It
@@ -133,7 +140,7 @@ def print_usage():
 
         For more information please refer to the GitHub project page
         at https://github.com/paylogic/pip-accel
-    """).strip()
+    """).strip())
 
 def clear_build_directory(directory):
     """
@@ -205,7 +212,7 @@ def download_source_dists(arguments, build_directory):
     try:
         run_pip(arguments + ['--no-install'], use_remote_index=True, build_directory=build_directory)
         logger.info("Finished downloading source distributions in %s.", download_timer)
-    except Exception, e:
+    except Exception as e:
         logger.warn("pip raised an exception while downloading source distributions: %s.", e)
 
 def install_requirements(requirements, install_prefix=ENVIRONMENT):
@@ -312,7 +319,7 @@ class CustomInstallCommand(InstallCommand):
             self.intercepted_exception = None
             self.requirement_set = original_method(*args, **kw)
             return self.requirement_set
-        except (Exception, KeyboardInterrupt), e:
+        except (Exception, KeyboardInterrupt) as e:
             self.intercepted_exception = e
             raise
 
@@ -324,9 +331,9 @@ def update_source_dists_index():
     link_timer = Timer()
     for download_name in os.listdir(download_cache):
         download_path = os.path.join(download_cache, download_name)
-        url = urllib.unquote(download_name)
+        url = unquote(download_name)
         if not url.endswith('.content-type'):
-            components = urlparse.urlparse(url)
+            components = urlparse(url)
             archive_name = os.path.basename(components.path)
             archive_path = os.path.join(source_index, add_extension(download_path, archive_name))
             if not os.path.isfile(archive_path):
@@ -355,18 +362,18 @@ def add_extension(download_path, archive_path):
     on PyPI, but that would add a binary dependency to ``pip-accel`` and I
     don't want that :-).
     """
-    handle = open(download_path)
+    handle = open(download_path, 'rb')
     header = handle.read(2)
     handle.close()
-    if header.startswith('\x1f\x8b'):
+    if header.startswith(b'\x1f\x8b'):
         # The gzip compression header is two bytes: 0x1F, 0x8B.
         if not archive_path.endswith(('.tgz', '.tar.gz')):
             archive_path += '.tar.gz'
-    elif header.startswith('BZ'):
+    elif header.startswith(b'BZ'):
         # The bzip2 compression header is two bytes: B, Z.
         if not archive_path.endswith('.bz2'):
             archive_path += '.bz2'
-    elif header.startswith('PK'):
+    elif header.startswith(b'PK'):
         # According to Wikipedia, ZIP archives don't have an official magic
         # number, but most of the time we'll find two bytes: P, K (for Phil
         # Katz, creator of the format).
